﻿using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace MergeByDefect
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        Engine scmEngine;
        
        private void frmMain_Load(object sender, EventArgs e)
        {

            
            //production
            GlobaVars.scmMainline = System.Environment.GetEnvironmentVariable("SSCM_MAINLINE");
            GlobaVars.scmSrcBranch = System.Environment.GetEnvironmentVariable("SSCM_BRANCH");
            GlobaVars.scmRepository = System.Environment.GetEnvironmentVariable("SSCM_REPOSITORY");
            GlobaVars.scmFile = System.Environment.GetEnvironmentVariable("SSCM_FILE");
            

            //Debug
            /*
            GlobaVars.scmMainline = "<mainline to test>";
            GlobaVars.scmSrcBranch = "<branch to test>";
            GlobaVars.scmRepository = "<repo to test>";
            GlobaVars.scmFile = "<file to test>";
            */


            txtSrcBranch.Text = GlobaVars.scmSrcBranch;
            txtSrcFile.Text = GlobaVars.scmRepository + "/" + GlobaVars.scmFile;

            CMConfig config = new CMConfig(Application.StartupPath);



            if (config.Exists())
            {

                scmEngine = new Engine();
                string fileType = scmEngine.CheckFileType();
                if (fileType.Equals("Text"))
                {
                    PopulateControls();

                }
                else if (fileType.Contains("UTF"))
                {
                    if (MessageBox.Show("The selected file has unicode encoding.\nPatch might not be able to properly merge this file.\nContinue?", "MergeByDefect", MessageBoxButtons.YesNo) == DialogResult.Yes)
                    {
                        PopulateControls();
                    }
                    else
                    {
                        Application.Exit();
                    }

                }
                else if (fileType.Equals("AutoDetect"))
                {
                    MessageBox.Show("The file you have selected does not reside in the selected repository.\nYou probably are listing your files recursively");
                    Application.Exit();
                }
                else
                {
                    MessageBox.Show("This file type can not be merged.");
                    Application.Exit();
                }
            }
            else
            {
                MessageBox.Show("Configuration file not found!");
                Application.Exit();
            }
        }
        private void PopulateControls()
        {

            ArrayList items = scmEngine.GetDefectHistory();
            if (items.Count == 0)
            {
                MessageBox.Show("The selected file does not have any Attach to Defect events!", "MergeByDefect");
                Application.Exit();
            }
            else
            {
                for (int i = 0; i < items.Count; i++)
                {
                    cmbDefectNums.Items.Add(items[i].ToString());
                }
            }

        }
        private void btnCancel_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void btnMerge_Click(object sender, EventArgs e)
        {
            if (txtDstBranch.Text.Equals("") || cmbDefectNums.Text.Equals(""))
            {
                MessageBox.Show("Make sure a version and branch are selected!","MergeByDefect");
            }
            else if (txtDstBranch.Text.Equals(txtSrcBranch.Text))
            {
                MessageBox.Show("The source and destination branches can not be the same!","MergeByDefect");
            }
            else
            {
                string selVersion = cmbDefectNums.Text;
                GlobaVars.scmDstBranch = txtDstBranch.Text;
                int version = 0;
                try
                {

                    //Extract the version - # (version #)
                    int start = selVersion.IndexOf('n');
                    int end = selVersion.IndexOf(')');
                    if ((start > -1) && (end > -1))
                    {
                        if (end > start)
                        {
                            start = start + 2;
                            int length = end - start;
                            selVersion = selVersion.Substring(start, length);
                            version = Convert.ToInt16(selVersion);
                            scmEngine.Merge(version);
                        }
                        else
                        {
                            MessageBox.Show("Unable to determine the version number.", "MergeByDefect");
                        }
                    }
                    else
                    {
                        MessageBox.Show("Unable to determine the version number.", "MergeByDefect");
                    }
                }
                catch (Exception fcc)
                {
                    MessageBox.Show("Unable to determine the version number.\n" + fcc.Message, "MergeByDefect");
                }


            }
        }

        private void btnBrowseBranch_Click(object sender, EventArgs e)
        {
            frmBranchBrowser browser = new frmBranchBrowser(this);
            browser.Show();
        }
    }
}
